@@ -1,6 +1,7 @@
 from django import template
 from django.forms import ChoiceField
 from django.conf.urls.defaults import patterns, url
+from django.core.urlresolvers import get_urlconf, get_resolver
 from django.utils.translation import ugettext_lazy as _
 from django.utils.safestring import mark_safe
 from django.http import HttpResponseRedirect
@@ -132,6 +133,21 @@ class TreeItemAdmin(admin.ModelAdmin):
         my_choice_field.help_text = form.base_fields['parent'].help_text
         # Replace 'parent' TreeItem field with new appropriate one
         form.base_fields['parent'] = my_choice_field
+
+        # Try to resolve all currently registered url names.
+        if not getattr(self, 'known_url_names', False):
+            self.known_url_names = []
+            self.known_url_rules = []
+            reverse_dict = get_resolver(get_urlconf()).reverse_dict
+            for url_name, url_rules in reverse_dict.items():
+                if isinstance(url_name, basestring):
+                    self.known_url_names.append(url_name)
+                    self.known_url_rules.append('<b>%s</b> %s' % (url_name, ' '.join(url_rules[0][0][1])))
+            self.known_url_rules = sorted(self.known_url_rules)
+
+        form.known_url_names_hint = _('You are seeing this warning because "URL as Pattern" option is active and pattern entered above seems to be invalid. Currently registered URL pattern names and parameters: ')
+        form.known_url_names = self.known_url_names
+        form.known_url_rules = self.known_url_rules
         return form
 
     def get_tree(self, tree_id):
