@@ -114,7 +114,7 @@ class SiteTree(object):
 
     def cache_empty(self, **kwargs):
         """Empties cached sitetree data."""
-        self.cache = False
+        self.cache = None
         cache.delete('sitetrees')
         cache.delete('tree_aliases')
 
@@ -140,7 +140,7 @@ class SiteTree(object):
         if not self.global_context or hash(context) != hash(self.global_context):
             self.global_context = context
 
-    def resolve_tree_i18_alias(self, alias):
+    def resolve_tree_i18n_alias(self, alias):
         """Resolves internationalized tree alias.
         Verifies whether a separate sitetree is available for currently active language.
         If so, returns i18n alias. If not, returns the initial alias.
@@ -159,12 +159,14 @@ class SiteTree(object):
     def get_sitetree(self, alias):
         """Gets site tree items from the given site tree.
         Caches result to dictionary.
-        Returns items.
+        Returns (tree alias, tree items) tuple.
 
         """
         self.cache_init()
         sitetree_needs_caching = False
-        alias = self.resolve_tree_i18_alias(alias)
+        if self.global_context.current_app != 'admin':
+            # We do not need i18n for a tree rendered in Admin dropdown.
+            alias = self.resolve_tree_i18n_alias(alias)
         sitetree = self.get_cache_entry('sitetrees', alias)
         if not sitetree:
             sitetree = TreeItem.objects.select_related('parent', 'tree').\
@@ -213,7 +215,7 @@ class SiteTree(object):
         if sitetree_needs_caching:
             self.cache_save()
 
-        return sitetree
+        return alias, sitetree
 
     def calculate_item_depth(self, tree_alias, item_id, depth=0):
         """Calculates depth of the item in the tree."""
@@ -347,7 +349,7 @@ class SiteTree(object):
         # Resolve tree_alias from the context.
         tree_alias = self.resolve_var(tree_alias)
         # Get tree.
-        sitetree_items = self.get_sitetree(tree_alias)
+        tree_alias, sitetree_items = self.get_sitetree(tree_alias)
         # No items in tree, fail silently.
         if not sitetree_items:
             return False, False
@@ -479,7 +481,7 @@ class SiteTree(object):
         # Resolve tree_alias from the context.
         tree_alias = self.resolve_var(tree_alias)
         # Get tree.
-        self.get_sitetree(tree_alias)
+        tree_alias, tree_items = self.get_sitetree(tree_alias)
         # Mark path to current item.
         self.tree_climber(tree_alias, self.get_tree_current_item(tree_alias))
 
@@ -493,7 +495,9 @@ class SiteTree(object):
         return my_template.render(context)
 
     def get_children(self, tree_alias, item):
-        tree_alias = self.resolve_tree_i18_alias(tree_alias)
+        if self.global_context.current_app != 'admin':
+            # We do not need i18n for a tree rendered in Admin dropdown.
+            tree_alias = self.resolve_tree_i18n_alias(tree_alias)
         return self.get_cache_entry('parents', tree_alias)[item]
 
     def update_has_children(self, tree_alias, tree_items, navigation_type):
